Documentation
¶
Index ¶
- func GetInt(path ...string) int
- func GetString(path ...string) string
- func GetStringArray(path ...string) []string
- func GetStringMap(path ...string) map[string]string
- func Map() map[string]interface{}
- func New(sources ...string) error
- func Reload() error
- func Scan(t interface{}, path ...string) error
- func Watch() (goconfig.Watcher, error)
- func WithEtcd(opt ...source.Option)
- func WithEtcdAddress(addr ...string) source.Option
- func WithEtcdAuth(user, pass string) source.Option
- func WithEtcdTLSAuth(certFile, keyFile, caFile string) source.Option
- func WithPath(path string) source.Option
- type Config
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetStringArray ¶
func GetStringMap ¶
func New ¶
New will load config from various config file file in Json format if same config param available in environment, environment param will take higher priority
func WithEtcdAddress ¶
func WithEtcdAuth ¶ added in v1.0.17
func WithEtcdTLSAuth ¶ added in v1.0.17
Types ¶
Click to show internal directories.
Click to hide internal directories.